==========
Background
==========

This version of the :app:`Pyramid` wiki tutorial presents a
:app:`Pyramid` application that uses technologies which will be
familiar to someone with :term:`Zope` experience.  It uses
:term:`ZODB` as a persistence mechanism and :term:`traversal` to map
URLs to code.  It can also be followed by people without any prior
Python web framework experience.

To code along with this tutorial, the developer will need a UNIX
machine with development tools (Mac OS X with XCode, any Linux or BSD
variant, etc) *or* a Windows system of any kind.

This tutorial targets :app:`Pyramid` version 1.0.

Have fun!
